@@ -100,15 +100,21 @@ class TestBuild(unittest.TestCase):
                 "SELECT x FROM tbl LEFT OUTER JOIN tbl2",
             ),
             (
-                lambda: select("x").from_("tbl").join(exp.Table(this="tbl2"), join_type="left outer"),
+                lambda: select("x")
+                .from_("tbl")
+                .join(exp.Table(this="tbl2"), join_type="left outer"),
                 "SELECT x FROM tbl LEFT OUTER JOIN tbl2",
             ),
             (
-                lambda: select("x").from_("tbl").join(exp.Table(this="tbl2"), join_type="left outer", join_alias="foo"),
+                lambda: select("x")
+                .from_("tbl")
+                .join(exp.Table(this="tbl2"), join_type="left outer", join_alias="foo"),
                 "SELECT x FROM tbl LEFT OUTER JOIN tbl2 AS foo",
             ),
             (
-                lambda: select("x").from_("tbl").join(select("y").from_("tbl2"), join_type="left outer"),
+                lambda: select("x")
+                .from_("tbl")
+                .join(select("y").from_("tbl2"), join_type="left outer"),
                 "SELECT x FROM tbl LEFT OUTER JOIN (SELECT y FROM tbl2)",
             ),
             (
@@ -131,7 +137,9 @@ class TestBuild(unittest.TestCase):
                 "SELECT x FROM tbl LEFT OUTER JOIN (SELECT y FROM tbl2) AS aliased",
             ),
             (
-                lambda: select("x").from_("tbl").join(parse_one("left join x", into=exp.Join), on="a=b"),
+                lambda: select("x")
+                .from_("tbl")
+                .join(parse_one("left join x", into=exp.Join), on="a=b"),
                 "SELECT x FROM tbl LEFT JOIN x ON a = b",
             ),
             (
@@ -139,7 +147,9 @@ class TestBuild(unittest.TestCase):
                 "SELECT x FROM tbl LEFT JOIN x ON a = b",
             ),
             (
-                lambda: select("x").from_("tbl").join("select b from tbl2", on="a=b", join_type="left"),
+                lambda: select("x")
+                .from_("tbl")
+                .join("select b from tbl2", on="a=b", join_type="left"),
                 "SELECT x FROM tbl LEFT JOIN (SELECT b FROM tbl2) ON a = b",
             ),
             (
@@ -162,7 +172,10 @@ class TestBuild(unittest.TestCase):
             (
                 lambda: select("x", "y", "z")
                 .from_("merged_df")
-                .join("vte_diagnosis_df", using=[exp.to_identifier("patient_id"), exp.to_identifier("encounter_id")]),
+                .join(
+                    "vte_diagnosis_df",
+                    using=[exp.to_identifier("patient_id"), exp.to_identifier("encounter_id")],
+                ),
                 "SELECT x, y, z FROM merged_df JOIN vte_diagnosis_df USING (patient_id, encounter_id)",
             ),
             (
@@ -222,7 +235,10 @@ class TestBuild(unittest.TestCase):
                 "SELECT x, y, z, a FROM tbl ORDER BY x, y, z, a",
             ),
             (
-                lambda: select("x", "y", "z", "a").from_("tbl").cluster_by("x, y", "z").cluster_by("a"),
+                lambda: select("x", "y", "z", "a")
+                .from_("tbl")
+                .cluster_by("x, y", "z")
+                .cluster_by("a"),
                 "SELECT x, y, z, a FROM tbl CLUSTER BY x, y, z, a",
             ),
             (
@@ -239,7 +255,9 @@ class TestBuild(unittest.TestCase):
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl",
             ),
             (
-                lambda: select("x").from_("tbl").with_("tbl", as_="SELECT x FROM tbl2", recursive=True),
+                lambda: select("x")
+                .from_("tbl")
+                .with_("tbl", as_="SELECT x FROM tbl2", recursive=True),
                 "WITH RECURSIVE tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl",
             ),
             (
@@ -247,7 +265,9 @@ class TestBuild(unittest.TestCase):
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl",
             ),
             (
-                lambda: select("x").from_("tbl").with_("tbl (x, y)", as_=select("x", "y").from_("tbl2")),
+                lambda: select("x")
+                .from_("tbl")
+                .with_("tbl (x, y)", as_=select("x", "y").from_("tbl2")),
                 "WITH tbl(x, y) AS (SELECT x, y FROM tbl2) SELECT x FROM tbl",
             ),
             (
@@ -258,7 +278,10 @@ class TestBuild(unittest.TestCase):
                 "WITH tbl AS (SELECT x FROM tbl2), tbl2 AS (SELECT x FROM tbl3) SELECT x FROM tbl",
             ),
             (
-                lambda: select("x").from_("tbl").with_("tbl", as_=select("x", "y").from_("tbl2")).select("y"),
+                lambda: select("x")
+                .from_("tbl")
+                .with_("tbl", as_=select("x", "y").from_("tbl2"))
+                .select("y"),
                 "WITH tbl AS (SELECT x, y FROM tbl2) SELECT x, y FROM tbl",
             ),
             (
@@ -266,35 +289,59 @@ class TestBuild(unittest.TestCase):
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").group_by("x"),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .group_by("x"),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl GROUP BY x",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").order_by("x"),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .order_by("x"),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl ORDER BY x",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").limit(10),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .limit(10),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl LIMIT 10",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").offset(10),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .offset(10),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl OFFSET 10",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").join("tbl3"),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .join("tbl3"),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl JOIN tbl3",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").distinct(),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .distinct(),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT DISTINCT x FROM tbl",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").where("x > 10"),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .where("x > 10"),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl WHERE x > 10",
             ),
             (
-                lambda: select("x").with_("tbl", as_=select("x").from_("tbl2")).from_("tbl").having("x > 20"),
+                lambda: select("x")
+                .with_("tbl", as_=select("x").from_("tbl2"))
+                .from_("tbl")
+                .having("x > 20"),
                 "WITH tbl AS (SELECT x FROM tbl2) SELECT x FROM tbl HAVING x > 20",
             ),
             (lambda: select("x").from_("tbl").subquery(), "(SELECT x FROM tbl)"),
@@ -354,7 +401,9 @@ class TestBuild(unittest.TestCase):
                 "SELECT x FROM (SELECT x FROM tbl) AS foo WHERE x > 0",
             ),
             (
-                lambda: exp.subquery("select x from tbl UNION select x from bar", "unioned").select("x"),
+                lambda: exp.subquery("select x from tbl UNION select x from bar", "unioned").select(
+                    "x"
+                ),
                 "SELECT x FROM (SELECT x FROM tbl UNION SELECT x FROM bar) AS unioned",
             ),
             (
