@@ -525,24 +525,14 @@ class TestExpressions(unittest.TestCase):
             ),
             exp.Properties(
                 expressions=[
-                    exp.FileFormatProperty(
-                        this=exp.Literal.string("FORMAT"), value=exp.Literal.string("parquet")
-                    ),
+                    exp.FileFormatProperty(this=exp.Literal.string("parquet")),
                     exp.PartitionedByProperty(
-                        this=exp.Literal.string("PARTITIONED_BY"),
-                        value=exp.Tuple(
-                            expressions=[exp.to_identifier("a"), exp.to_identifier("b")]
-                        ),
+                        this=exp.Tuple(expressions=[exp.to_identifier("a"), exp.to_identifier("b")])
                     ),
-                    exp.AnonymousProperty(
-                        this=exp.Literal.string("custom"), value=exp.Literal.number(1)
-                    ),
-                    exp.TableFormatProperty(
-                        this=exp.Literal.string("TABLE_FORMAT"),
-                        value=exp.to_identifier("test_format"),
-                    ),
-                    exp.EngineProperty(this=exp.Literal.string("ENGINE"), value=exp.null()),
-                    exp.CollateProperty(this=exp.Literal.string("COLLATE"), value=exp.true()),
+                    exp.Property(this=exp.Literal.string("custom"), value=exp.Literal.number(1)),
+                    exp.TableFormatProperty(this=exp.to_identifier("test_format")),
+                    exp.EngineProperty(this=exp.null()),
+                    exp.CollateProperty(this=exp.true()),
                 ]
             ),
         )
@@ -609,9 +599,9 @@ FROM foo""",
             """SELECT
   a,
   b AS B,
-  c, -- comment
-  d AS D, -- another comment
-  CAST(x AS INT) -- final comment
+  c, /* comment */
+  d AS D, /* another comment */
+  CAST(x AS INT) /* final comment */
 FROM foo""",
         )
 
